@@ -78,6 +78,22 @@ lda_suffstats* new_lda_suffstats(lda_model* model)
     return(ss);
 }
 
+/*
+ * deallocate sufficient statistics
+ *
+ */
+
+void free_lda_suffstats(lda_suffstats* ss, int num_topics, int num_terms)
+{
+    int i, j;
+
+    free(ss->class_total);
+    for (i = 0; i < num_topics; i++)
+    {
+	free(ss->class_word[i]);
+    }
+    free(ss->class_word);
+}
 
 /*
  * various intializations for the sufficient statistics
